import { Post } from "@/.contentlayer/generated"
import MDXImage from "./MDXImage"

import { format, parseISO } from 'date-fns'

export default function PostHeader(post: Post) {

    const numberToWord = (num: number) => {
        switch(num) {
            case 1: return "one";
            case 2: return "two";
            case 3: return "three";
            case 4: return "four";
        }
      }
      
    return (<>
        { ( post.cover && post.cover_alt ) ? (
          <div className="mb-4">
            <MDXImage src={post.cover} alt={post.cover_alt}/>
          </div>
        ) : '' }
       
        <h1 className="text-4xl font-serif font-bold text-title">{post.title}</h1>
        <h2 className="font-mono">&mdash; {format(parseISO(post.date), 'LLLL d, yyyy')}
          {(post.updated) ? (
            <span>, <span className="text-subtitle">updated {format(parseISO(post.updated), 'LLLL d, yyyy')}</span></span>
          ) : ''}
        </h2>
        <h2 className="text-sm italic mb-4 text-subtitle">{post.summary}</h2>

        {(post.toc) ? ( <>
            <h3 className="font-mono text-xl text-title">table of contents</h3>
            <div id="toc" className="mb-4 ml-2 pl-2 border-l border-neutral-400 ">
                {post.headings.map((heading: {level: number, text: string, slug: string}) => {
                return (
                    <div key={`#${heading.slug}`}>
                    <a className="font-serif text-sm text-subtitle hover:underline data-[level=two]:pl-3 data-[level=three]:pl-6" data-level={numberToWord(heading.level)} href={'#' + heading.slug}>
                        {(heading.level > 1) ? '> ' : ''}
                        {heading.text}
                    </a>
                    </div>
                )
                })}
            </div>
        </>):''}
    </>)
}